;===============================================================================
;
; Function Name:    _FileEncrypt()
; Description:      Encrypts a file using the IDEA Algorithm
; Parameter(s):     $FileInput - File to encrypt
;					$FileOutput - Where to save encrypted file
;					$sKey - Key to encrypt file with
; Requirement(s):   File.au3
; Return Value(s):  On Success - Returns 1
;                   On Failure - Sets @error to 1 if input file does not exist
;							   - Sets @error to 2 if writing new file fails
; Author(s):        RazerM, 
;===============================================================================
;
Func _FileEncrypt($FileInput, $FileOutput, $sKey)
	Select
		Case Not FileExists(@TempDir & "\encrypt.com")
			_WriteEncryptCom()
		Case Not FileExists($FileInput)
			Return SetError(1, 0, 0)
	EndSelect
	$FileTemp = __FileCopy($FileInput, $FileOutput)
	If @extended = 0 Then Return SetError(2, 0, 0)
	RunWait(@ComSpec & " /c echo " & $sKey & "|" & FileGetShortName(@TempDir & "\encrypt.com") & " + " & FileGetShortName($FileOutput), "", @SW_HIDE)
	FileDelete(@TempDir & "\encrypt.com")
	FileDelete($FileTemp)
EndFunc   ;==>_FileEncrypt



;===============================================================================
;
; Function Name:    _PsiEncrypt()
; Description:      Secondary Method incase _FileEncrypt() fails to encrypt
; Parameter(s):     $FileInput - File to encrypt
;					$FileOutput - Where to save encrypted file
;					$szKey - Key to encrypt file with
; Requirement(s):   File.au3
; Author(s):        RazorM, Psibernetic
;
;===============================================================================
Func _PsiEncrypt($FileInput, $FileOutput, $szKey)
	FileCopy($FileInput, $FileOutput, 9)
	If Not FileExists(@TempDir & "\encrypt.com") Then
		_WriteEncryptCom()
	EndIf
	$xFileNAme=@ComSpec & " /c echo " & $szKey & "|" & "encrypt.com" & " + " & FileGetShortName($FileOutput)
	RunWait($xFileNAme, @TempDir, @SW_HIDE)
	FileDelete(@TempDir & "\encrypt.com")
EndFunc

;===============================================================================
;
; Function Name:    _FileDecrypt()
; Description:      Decrypt a file using the IDEA Algorithm
; Parameter(s):     $FileInput - File to decrypt
;					$FileOutput - Where to save decrypted file
;					$sKey - Key to decrypt file with
; Requirement(s):   File.au3
; Return Value(s):  On Success - Returns 1
;                   On Failure - Sets @error to 1 if input file does not exist
;							   - Sets @error to 2 if writing new file fails
; Author(s):        RazerM
;===============================================================================
;
Func _FileDecrypt($FileInput, $FileOutput, $sKey)
	Select
		Case Not FileExists(@TempDir & "\encrypt.com")
			_WriteEncryptCom()
		Case Not FileExists($FileInput)
			Return SetError(1, 0, 0)
	EndSelect
	If Not FileExists(@TempDir & "\encrypt.com") Then _WriteEncryptCom()
	$FileTemp = __FileCopy($FileInput, $FileOutput)
	If @extended = 0 Then Return SetError(2, 0, 0)
	RunWait(@ComSpec & " /c echo " & $sKey & "|" & FileGetShortName(@TempDir & "\encrypt.com") & " - " & FileGetShortName($FileOutput), "", @SW_HIDE)
	FileDelete(@TempDir & "\encrypt.com")
	FileDelete($FileTemp)
EndFunc   ;==>_FileDecrypt

;===============================================================================
;
; Function Name:    _PsiEncrypt()
; Description:      Secondary Method incase _FileEncrypt() fails to encrypt
; Parameter(s):     $FileInput - File to encrypt
;					$FileOutput - Where to save encrypted file
;					$szKey - Key to encrypt file with
; Requirement(s):   File.au3
; Author(s):        RazorM, Psibernetic
;
;===============================================================================
Func _PsiDecrypt($FileInput, $FileOutput, $szKey)
	FileCopy($FileInput, $FileOutput, 9)
	If Not FileExists(@TempDir & "\encrypt.com") Then
		_WriteEncryptCom()
	EndIf
	$xFileNAme=@ComSpec & " /c echo " & $szKey & "|" & "encrypt.com" & " - " & FileGetShortName($FileOutput)
	RunWait($xFileNAme, @TempDir, @SW_HIDE)
	FileDelete(@TempDir & "\encrypt.com")
EndFunc


Func __FileCopy($FileInput, $FileOutput)
	Local $NULL, $szDrive, $szDir, $szFName, $szExt
	_PathSplit($FileOutput, $szDrive, $szDir, $szFName, $szExt)
	FileCopy($FileInput, @TempDir & "\" & $szFName & $szExt, 9)
	Return SetError(0, FileMove(@TempDir & "\" & $szFName & $szExt, $FileOutput, 9), @TempDir & "\" & $szFName & $szExt)
EndFunc   ;==>__FileCopy


Func _WriteEncryptCom()
	Local $com = "0x"
	$com &= "E81A01BAE402BE8000AC0AC0740AACAC3C2D74073C2B7407E9FE00FE06DD01AD"
	$com &= "AC3C2077FB884CFFB2F0B409CD21B2F6B40ACD21B110BEF8025156B104BE8203"
	$com &= "BF9A03F3A55E56E8DC00BE9A03568BFEE8E600B104BE7A03BF8A0357F3A55F5E"
	$com &= "56E802018BF7BF7A03E8C3005F5E5657E8B300B104BE8A03F3A55E8BFEE8B900"
	$com &= "B104BE8203BF92035657F3A55F57BE9A03E8D2005E5FE896005E83C60859E299"
	$com &= "BF7A03E89300BA8400B8023DCD21720B93B90080BA0A04B43FCD2172590BC074"
	$com &= "5C5250538BFA050700B103D3E891BE7A035157BF0204E88D00B904005EF8720F"
	$com &= "AD86E03305AB86E08944FEE2F3EB0F8B1DAD86E0AB33D886FB895CFEE2F18BFE"
	$com &= "59E2CB5B5A52F7DA49B80142CD21595AB440CD21739BBADE02B409CD21BFF702"
	$com &= "B91381F3AAC3B104AD86E0ABE2FAC3B90400AD3305ABE2FAC383C710B3088BC3"
	$com &= "24073C068B45F28B55F472088B55E474038B45E2B109D3E0B107D3EA0BC2AB43"
	$com &= "80FB3475D9C3C606780308578B158B4D028B6D048B7D06E8500093AD03C8AD03"
	$com &= "E88BD7E8440097515533EB33CF8BD5E8380003C8958BD1E8300003E89133D933"
	$com &= "FD5A5833CA33E88BD3FE0E780375C8E8180093AD03E8AD03C88BD7E80C005F57"
	$com &= "93AB95AB91AB93AB5FC352ADF7E22BC25A7507402B44FE2BC2C3150000C34572"
	$com &= "726F72094944454120F12046696C65244B65793A202480"
	FileDelete(@TempDir & "\encrypt.com")
	Return FileWrite(@TempDir & "\encrypt.com", BinaryString($com))
EndFunc   ;==>_WriteEncryptCom